@@ -35,6 +35,11 @@
 #include "debug.h"
 #include <string.h>
 
+#if OPENSSL_VERSION_NUMBER >= 0x10100000L
+# define X509_set_notBefore X509_set1_notBefore
+# define X509_set_notAfter X509_set1_notAfter
+#endif
+
 CK_RV do_store_cert(CK_BYTE_PTR data, CK_ULONG len, X509 **cert) {
 
   const unsigned char *p = data; // Mandatory temp variable required by OpenSSL
@@ -70,6 +75,8 @@ CK_RV do_create_empty_cert(CK_BYTE_PTR in, CK_ULONG in_len, CK_BBOOL is_rsa,
   RSA       *rsa = NULL;
   BIGNUM    *bignum_n = NULL;
   BIGNUM    *bignum_e = NULL;
+  BIGNUM    *bignum_prv = NULL;
+  unsigned char zeroes[512] = {0};
   EC_KEY    *eck = NULL;
   EC_GROUP  *ecg = NULL;
   EC_POINT  *ecp = NULL;
@@ -110,13 +117,20 @@ CK_RV do_create_empty_cert(CK_BYTE_PTR in, CK_ULONG in_len, CK_BBOOL is_rsa,
     if(*data_ptr != 0x82)
       goto create_empty_cert_cleanup;
 
+    // OpenSSL 1.1 doesn't allow to set empty signatures
+    // Use a bogus private key
+    bignum_prv = BN_bin2bn(zeroes, len, NULL);
+    if (bignum_prv == NULL)
+      goto create_empty_cert_cleanup;
+
     data_ptr++;
     data_ptr += get_length(data_ptr, &len);
     bignum_e = BN_bin2bn(data_ptr, len, NULL);
     if(bignum_e == NULL)
       goto create_empty_cert_cleanup;
 
-    RSA_set0_key(rsa, bignum_n, bignum_e, NULL);
+    if (RSA_set0_key(rsa, bignum_n, bignum_e, bignum_prv) == 0)
+      goto create_empty_cert_cleanup;
 
     if (EVP_PKEY_set1_RSA(key, rsa) == 0)
       goto create_empty_cert_cleanup;
@@ -150,6 +164,15 @@ CK_RV do_create_empty_cert(CK_BYTE_PTR in, CK_ULONG in_len, CK_BBOOL is_rsa,
     if (EC_KEY_set_public_key(eck, ecp) == 0)
       goto create_empty_cert_cleanup;
 
+    // OpenSSL 1.1 doesn't allow to set empty signatures
+    // Use a bogus private key
+    bignum_prv = BN_bin2bn(zeroes, 65, NULL);
+    if (bignum_prv == NULL)
+      goto create_empty_cert_cleanup;
+
+    if (EC_KEY_set_private_key(eck, bignum_prv) == 0)
+      goto create_empty_cert_cleanup;
+
     if (EVP_PKEY_set1_EC_KEY(key, eck) == 0)
       goto create_empty_cert_cleanup;
   }
@@ -165,18 +188,9 @@ CK_RV do_create_empty_cert(CK_BYTE_PTR in, CK_ULONG in_len, CK_BBOOL is_rsa,
   X509_set_notBefore(cert, tm);
   X509_set_notAfter(cert, tm);
 
-#if OPENSSL_VERSION_NUMBER < 10100000L
-  // Manually set the signature algorithms.
-  // OpenSSL 1.0.1i complains about empty DER fields
-  // 8 => md5WithRsaEncryption
-  cert->sig_alg->algorithm = OBJ_nid2obj(8);
-  cert->cert_info->signature->algorithm = OBJ_nid2obj(8);
-
-  // Manually set a signature (same reason as before)
-  ASN1_BIT_STRING_set_bit(cert->signature, 8, 1);
-  ASN1_BIT_STRING_set(cert->signature, (unsigned char*)"\x00", 1);
-  ASN1_BIT_STRING_set(cert->signature, (unsigned char*)"\x00", 1);
-#endif
+  // Write a bogus signature to make a valid certificate
+  if (X509_sign(cert, key, EVP_sha1()) == 0)
+    goto create_empty_cert_cleanup;
 
   len = i2d_X509(cert, NULL);
   if (len < 0)
@@ -218,10 +232,10 @@ create_empty_cert_cleanup:
     bignum_e = NULL;
   }
 
-/*  if (rsa != NULL) { // TODO: adding this generates an error. Automatically free'd by EVP_PKEY_free ?
-    RSA_free(rsa);
-    rsa = NULL;
-    }*/
+  if (bignum_prv != NULL) {
+    BN_free(bignum_prv);
+    bignum_prv = NULL;
+  }
 
   if (ecp != NULL) {
     EC_POINT_free(ecp);
@@ -580,7 +594,9 @@ CK_RV do_pkcs_pss(ykcs11_rsa_key_t *key, CK_BYTE_PTR in, CK_ULONG in_len,
           int nid, CK_BYTE_PTR out, CK_ULONG_PTR out_len) {
   unsigned char em[RSA_size(key)];
 
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
   OpenSSL_add_all_digests();
+#endif
 
   DBG("Apply PSS padding to %lu bytes and get %d", in_len, RSA_size(key));
 
@@ -590,14 +606,18 @@ CK_RV do_pkcs_pss(ykcs11_rsa_key_t *key, CK_BYTE_PTR in, CK_ULONG in_len,
 
   // In case of raw PSS (no hash) this function will fail because OpenSSL requires an MD
   if (RSA_padding_add_PKCS1_PSS(key, em, out, EVP_get_digestbynid(nid), -2) == 0) {
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
     EVP_cleanup();
+#endif
     return CKR_FUNCTION_FAILED;
   }
 
   memcpy(out, em, sizeof(em));
   *out_len = (CK_ULONG) sizeof(em);
 
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
   EVP_cleanup();
+#endif
 
   return CKR_OK;
 }
